summaryrefslogtreecommitdiff
path: root/src/warning.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/warning.h')
-rw-r--r--src/warning.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/src/warning.h b/src/warning.h
index 778ee407..78e99893 100644
--- a/src/warning.h
+++ b/src/warning.h
@@ -17,7 +17,9 @@ this program. If not, see <https://www.gnu.org/licenses/>. */
/* Types of warnings we can show. */
enum warning_type
{
- wt_undefined_var = 0, /* Reference an undefined variable name. */
+ wt_invalid_var = 0, /* Assign to an invalid variable name. */
+ wt_invalid_ref, /* Reference an invalid variable name. */
+ wt_undefined_var, /* Reference an undefined variable name. */
wt_max
};